--[[
    Project: AtlasMajorCities
    Author: modefanz.eu ~ Modefanz Coding Team
    Discripton: Capital City NPC Browser for Atlas.
    Release Date: May.2009
    Release Version: 1.5
    Internal: AMC.15
]]--

LibStub("tekKonfig-AboutPanel").new(nil, "AtlasMajorCities")

local BabbleZone = AMC_GetLocaleLibBabble("LibBabble-Zone-3.0");
local BabbleFaction = AMC_GetLocaleLibBabble("LibBabble-Faction-3.0");
local BabbleRace = AMC_GetLocaleLibBabble("LibBabble-Race-3.0");

local AMCL = LibStub("AceLocale-3.0"):GetLocale("AtlasMajorCities");

local function lineMatches(line, search_text)
	local foundMatch = false;
	if (string.len(search_text) == 0) then
		foundMatch = true;
	else
	if ( string.gmatch ) then
		if ( string.gmatch(string.lower(line), search_text)() ) then
			foundMatch = true;
		end
		else
			if ( string.gfind(string.lower(line), search_text)() ) then
				foundMatch = true;
			end
		end
	end
	return foundMatch;
end

function AtlasMajorCitiesSearch(data, text)
	local new = {};         -- create a new table
	local i;
	local v;
	local n;
	
	local search_text = string.lower(text);
	local match;
	
	if ( data.Areas == nil ) then
		if ( search_text == "" ) then
			new = data;
		else
			search_text = search_text:gsub("([%^%$%(%)%%%.%[%]%+%-%?])", "%%%1");
			search_text = search_text:gsub("%*", ".*");
			
			i, v = next(data, nil);      -- i is an index of data, v = data[i]
			n = i;
			while i do
				if ( type(i) == "number" ) then
					if ( string.gmatch ) then
						match = string.gmatch(string.lower(data[i]), search_text)();
					else
						match = string.gfind(string.lower(data[i]), search_text)();
					end
					
					if ( match ) then
						new[n] = { data[i] };
						n = n + 1;
					end
				end
				i, v = next(data, i);         -- get next index
			end
		end
	else
		n = 1;
		local areaKey;
		local areaData;
		local addSeparator = false;
		local shownAreaTitle = false;
		
		for areaKey,areaData in pairs(data.Areas) do
			local color = areaData.Color;
			local areaName = areaData.Name;
			local labelsKey;
			local labelsData;
			addSeparator = false;
			shownAreaTitle = false;
	
			for labelsKey,labelsData in pairs(areaData) do
				local labelKey;
				local labelData;
	
				if ( type(labelsData) == "table" and labelsData.Label ~= nil ) then
					local labelName = labelsData.Label;
					local foundMatch = false;
					for labelKey,labelData in ipairs(labelsData) do
						if (lineMatches(labelData, search_text)) then
							foundMatch = true;
							break;
						end
					end
	
					if ( foundMatch ) then
						for labelKey,labelData in ipairs(labelsData) do
							if (not shownAreaTitle) then
								new[n] = { color..areaName };
								n = n + 1;
								shownAreaTitle = true;
								if (lineMatches(labelData, search_text)) then
									new[n] = { " "..color..labelName..") "..labelData };
								else
									new[n] = { " ".."|c88888888"..labelName..") "..labelData };
								end
							else
								if ( labelKey > 1 ) then
									if (lineMatches(labelData, search_text)) then
										new[n] = { " ".."|c00000000"..labelName..") "..color..labelData };
									else
										new[n] = { " ".."|c00000000"..labelName..") ".."|c88888888"..labelData };
									end
								else
									if (lineMatches(labelData, search_text)) then
										new[n] = { " "..color..labelName..") "..labelData };
									else
										new[n] = { " ".."|c88888888"..labelName..") "..labelData };
									end
								end
							end
							n = n + 1;
							addSeparator = true;
						end
					end
				end
			end
			if (addSeparator) then
				new[n] = { " " };
				n = n + 1;
			end
		end
	end
	return new;
end


local BLUE = "|cff0066ff";
local GREY = "|cff999999";
local GREN = "|cff107106";
local YELL = "|cffcccc00";
local _RED = "|cffcc6666";
local ORNG = "|cffd3671b";
local PURP = "|cff7c2cd1";
local WHITE = "|cffffffff";
local CYAN = "|cff008888";
local INVIS = "|c00000000";
local LTBLU = "|cff0f6fcc";
local PINK = "|cffff3366";

local myCategory = AMCL["Major Cities"];

local myData = {
	Search = AtlasMajorCitiesSearch;

	-- Dalaran
	DL = {
		ZoneName = { BabbleZone["Dalaran"].." ("..BabbleFaction["Neutral"]..")" };
		Location = { BabbleZone["Crystalsong Forest"] };
		
		Areas = {
			-- Krasus Landing
			{
				Name = BabbleZone["Krasus' Landing"];
				Color = WHITE;
				{
					Label = "1";
					AMCL["Aludane Whitecloud"];
				},
				{
					Label = "2";
					AMCL["Hira Snowdawn"];
				},
				{
					Label = "3";
					AMCL["Officer Van Rossem"];
				},
				{
					Label = "4";
					AMCL["Sky-Reaver Klum"];
				}
		    },
		    -- Runeweaver Square
			{
				Name = AMCL["Runeweaver Square"];
				Color = ORNG;
				{
					Label = "S";
					AMCL["Entrance to the Sewers"];
		
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["Magical Menagerie"];
					AMCL["Mei Francis"];
					AMCL["Breanni"];
					AMCL["Tassia Whisperglen"];
				},
				{
					Label = "2";
					AMCL["Teleport to Violet Stand"];
					AMCL["Archmage Celindra"];
					AMCL["Warcaster Fanoraithe"];
					AMCL["Jessa Weaver"];
				},
				{
					Label = "3";
					AMCL["The Hunter's Reach"];
					AMCL["Dagna Flintlock"];
					AMCL["Jarold Puller"];
					AMCL["Aemara"];
				},
				{
					Label = "4";
					AMCL["Aerith Primrose"];
				},
				{
					Label = "5";
					AMCL["The Arsenal Absolute"];
					AMCL["Bartram Haller"];
					AMCL["Kerta the Bold"];
					AMCL["Valaden Silverblade"];
					AMCL["Walther Whiteford"];
				},
				{
					Label = "6";
					AMCL["Dalaran Visitor Center"];
					AMCL["Andrew Matthews"];
					AMCL["Elizabeth Ross"];
					AMCL["Archivist Betha"];
				},
				{
					Label = "7";
					AMCL["Curiosities & Moore"];
					AMCL["Debbi Moore"];
					AMCL["Brammold Deepmine"];
					AMCL["Orton Bennet"];
					AMCL["Ninsianna"];
				},
				{
					Label = "8";
					AMCL["Applebough"];
					AMCL["Windle Sparkshine"];
				},
				{
					Label = "9";
					AMCL["Sisters Sorcerous"];
					AMCL["Hagatha Moorehead"];
					AMCL["Endora Moorehead"];
				},
				{
					Label = "10";
					AMCL["The Threads of Fate"];
					AMCL["Paldesse"];
					AMCL["Karandonna"];
					AMCL["Sheddle Glossgleam"];
					AMCL["Chameli Banaphash"];
					AMCL["Norvin Alderman"];
				},
				{
					Label = "11";
					AMCL["The Wonderworks"];
					AMCL["Jepetto Joybuzz"];
					AMCL["Clockwork Assistant"];
				},
				{
					Label = "12";
					AMCL["The Legerdemain Lounge"];
					AMCL["Amisi Azuregaze"];
					AMCL["Arille Azuregaze"];
					AMCL["Sandra Bartan"];
					AMCL["Afsaneh Asrar"];
					AMCL["Stove"];
				},
				{
					Label = "13";
					AMCL["Bshop"];
					AMCL["Kizi Copperclip"];
				},
				{
					Label = "14";
					AMCL["One More Glass"];
					AMCL["Fialla Sweetberry"];
					AMCL["Christi Stockton"];
					AMCL["Lucian Trias"];
				},
				{
					Label = "15";
					AMCL["Aimee"];
				}
			},
			-- The Eventide
			{
				Name = AMCL["The Eventide"];
				Color = PURP;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "B";
					AMCL["Bank"];
				},
				{
					Label = "1";
					AMCL["Marcia Chase"];
					AMCL["Marcia Chase &"];
				},
				{
					Label = "2";
					AMCL["Glorious Goods"];
					AMCL["Jack Findle"];
					AMCL["Susana Averoy"];
				},
				{
					Label = "3";
					AMCL["Langrom's Leather & Links"];
					AMCL["Bragund Brightlink"];
					AMCL["Valerie Langrom"];
				},
				{
					Label = "4";
					AMCL["The Militant Mystic"];
					AMCL["Abra Cadabra"];
					AMCL["Shen Kang Cheng"];
				}
			},
			-- The Violet Hold
			{
				Name = AMCL["The Violet Hold"];
				Color = YELL;
				{
					Label = "1";
					AMCL["Archmage Timear"];
				},
				{
					Label = "2";
					AMCL["Archmage Lan'dalock"];
				},
				{
					Label = "3";
					AMCL["Torgo the Younger"];
				},
				{
					Label = "4";
					AMCL["The Violet Hold Instance"];
				}
			},
			-- The Silver Enclave a
			{
				Name = AMCL["The Silver Enclave a"];
				Color = BLUE;
				{
					Label = "I";
					AMCL["A Hero's Welcome"];
					AMCL["Isirami Fairwind"];
					AMCL["Stefen Cotter"];
					AMCL["Katherine Lee"];
					AMCL["Derek Odds"];
					AMCL["Inzi Charmlight"];
					AMCL["Marcella Bloom"];
					AMCL["Caliel Brightwillow"];
					AMCL["Stove"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["The Beer Garden"];
					AMCL["Laire Brewgold"];
					AMCL["Coira Longrifle"];
				},
				{
					Label = "2";
					AMCL["The Silver Enclave"];
					AMCL["PorStor"];
					AMCL["PorIron"];
					AMCL["PorDarn"];
					AMCL["PorExod"];
					AMCL["PorShat"];
				},
				{
					Label = "3";
					AMCL["The Silver Enclave"];
					AMCL["Arcanist Braedin"];
					AMCL["Alliance Brigadier"];
					AMCL["Portal to Battlefields"];
				},
				{
					Label = "4";
					AMCL["The Silver Enclave"];
					AMCL["Upstair"];
					AMCL["Arcanist Ivrenne"];
					AMCL["Arcanist Ivrenne &"];
					AMCL["Arcanist Adurin"];
					AMCL["Arcanist Firael"];
					AMCL["Arcanist Firael &"];
				}
			},
			-- The Violet Citadel
			{
				Name = AMCL["The Violet Citadel"];
				Color = GREN;
				{
					Label = "1";
					AMCL["Rhonin"];
					AMCL["Vereesa Windrunner"];
					AMCL["Vereesa Windrunner &"];
				},
				{
					Label = "2";
					AMCL["Archmage Alvareaux"];
				},
				{
					Label = "3";
					AMCL["Zidormi"];
					AMCL["Portal Cavern Time"];
				},
				{
					Label = "4";
					AMCL["Portal Purple Parlor"];
				},
				{
					Label = "5";
					AMCL["The Purple Parlor"];
					AMCL["Archmage John Nicholas"];
					AMCL["Alfred Copperworth"];
				}
			},
			-- The Magus Commerce
			{
				Name = AMCL["The Magus Commerce"];
				Color = GREY;
				{
					Label = "B";
					AMCL["Bank"];
				},
				{
					Label = "1";
					AMCL["Simply Enchanting"];
					AMCL["Enchanter Nalthanis"];
					AMCL["Enchanter Nalthanis &"];
					AMCL["Ildine Sorrowspear"];
					AMCL["Vanessa Sellers"];
				},
				{
					Label = "2";
					AMCL["First to Your Aid"];
					AMCL["Olisarra the Kind"];
					AMCL["Angelique Butler"];
				},
				{
					Label = "3";
					AMCL["Talismanic Textiles"];
					AMCL["Charles Worth"];
					AMCL["Dominique Stefano"];
					AMCL["Ainderu Summerleaf"];
					AMCL["Ainderu Summerleaf &"];
					AMCL["Lalla Brightweave"];
					AMCL["Linna Bruder"];
				},
				{
					Label = "4";
					AMCL["Legendary Leathers"];
					AMCL["Braeg Stoutbeard"];
					AMCL["Diane Cannings"];
					AMCL["Diane Cannings &"];
					AMCL["Derik Marks"];
					AMCL["Ranid Glowergold"];
					AMCL["Ranid Glowergold &"];
					AMCL["Manfred Staller"];
					AMCL["Manfred Staller &"];
					AMCL["Andellion"];
					AMCL["Namha Moonwater"];
					AMCL["Namha Moonwater &"];
				},
				{
					Label = "5";
					AMCL["Like Clockwork"];
					AMCL["Justin Oshenko"];
					AMCL["Justin Oshenko &"];
					AMCL["Bryan Landers"];
					AMCL["Didi the Wrench"];
					AMCL["Findle Whistlesteam"];
				},
				{
					Label = "6";
					AMCL["All That Glitters Prospecting Co"];
					AMCL["Jedidiah Handers"];
					AMCL["Dorian Fines"];
				},
				{
					Label = "7";
					AMCL["The Forge of Fate"];
				},
				{
					Label = "8";
					AMCL["Tanks For Everything"];
					AMCL["Alard Schmied"];
					AMCL["Alard Schmied &"];
					AMCL["Palja Amboss"];
					AMCL["Imindril Spearsong"];
					AMCL["Orland Schaeffer"];
					AMCL["Dubin Clay"];
					AMCL["Griselda Hunderland"];
					AMCL["Anthony Durain"];
				},
				{
					Label = "9";
					AMCL["The Magus Commerce"];
					AMCL["Dorothy Egan"];
					AMCL["Edward Egan"];
				},
				{
					Label = "10";
					AMCL["The Scribes Sacellum"];
					AMCL["Professor Pallin"];
					AMCL["Professor Pallin &"];
					AMCL["Larana Drome"];
					AMCL["Jessica Sellers"];
					AMCL["Theresa Wolf"];
				}
			},
			-- Sunreaver's Sanctuary
			{
				Name = AMCL["Sunreaver's Sanctuary"];
				Color = _RED;
				{
					Label = "I";
					AMCL["The Filthy Animal"];
					AMCL["Uda the Beast"];
					AMCL["Kyunghee"];
					AMCL["Mato"];
					AMCL["Hamaka"];
					AMCL["Umbiwa"];
					AMCL["Mimbihi"];
					AMCL["Awilo Lon'gomba"];
					AMCL["Awilo Lon'gomba &"];
					AMCL["Misensi"];
					AMCL["Abohba"];
					AMCL["Stove"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["PorOrgr"];
					AMCL["PorUnde"];
					AMCL["PorSilv"];
					AMCL["PorThBl"];
					AMCL["PorShat"];
				},
				{
					Label = "2";
					AMCL["Horde Warbringer"];
					AMCL["High Arcanist Savor"];
				},
				{
					Label = "3";
					AMCL["Magister Surdiel"];
					AMCL["Eye of the Storm Portal"];
					AMCL["Arathi Basin Portal"];
				},
				{
					Label = "4";
					AMCL["Strand of the Ancients Portal"];
					AMCL["Alterac Valley Portal"];
					AMCL["Warsong Gulch Portal"];
				},
				{
					Label = "5";
					AMCL["Magister Sarien"];
					AMCL["Magister Sarien &"];
					AMCL["Magister Brasael"];
					AMCL["Magistrix Lambriesse"];
					AMCL["Magistrix Lambriesse &"];
				},
			},
		},
	}, -- End of Dalaran

	-- Dal Sewers
	DLS = {
	    ZoneName = { BabbleZone["Dalaran Sewers"].."("..BabbleFaction["Neutral"]..")" };
	    Location = { BabbleZone["Crystalsong Forest"] };

	    Areas = {
	    	-- "D Sew
			{
				Name = AMCL["D Sew"];
				Color = WHITE;
				{
					Label = "E";
					AMCL["Entrance"];
				},
				{
					Label = "I";
					AMCL["Cantrips & Crows"];
					AMCL["Ajay Green"];
					AMCL["Narisa Redgold"];
					AMCL["Stove"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "B";
					AMCL["Bank"];
					AMCL["Binzik Goldbook"];
				},
				{
					Label = "1";
					AMCL["The Black Market"];
					AMCL["Hexil Garrot"];
					AMCL["Pazik The Pick"];
					AMCL["Scout Nisstina"];
					AMCL["Alchemist Cinesra"];
					AMCL["Darahir"];
				},
				{
					Label = "2";
					AMCL["Circle of Wills"];
					AMCL["Blazik Fireclaw"];
					AMCL["Nargle Lashcord"];
					AMCL["Xazi Smolderpipe"];
					AMCL["Zom Bocom"];
					AMCL["Shifty Vickers"];
				},
				{
					Label = "3";
					AMCL["Circle of Wills"];
					AMCL["Baroness Llana"];
					AMCL["Schembari Shearbolt"];
					AMCL["Schembari Shearbolt &"];
				},
				{
					Label = "4";
					AMCL["Circle of Wills"];
					AMCL["Rickard Rustbolt"];
				},
				{
					Label = "5";
					AMCL["Circle of Wills"];
					AMCL["Sarah Brady"];
					AMCL["Minzi Minx"];
				},
				{
					Label = "6";
					AMCL["Circle of Wills"];
					AMCL["Nixi Fireclaw"];
				},
				{
					Label = "7";
					AMCL["Circle of Wills"];
					AMCL["Kanika Goldwell"];
					AMCL["Ramik Slamwrench"];
				},
				{
					Label = "8";
					AMCL["Circle of Wills"];
					AMCL["Danik Blackshaft"];
				},
				{
					Label = "9";
					AMCL["Angelo Pescatore"];
				},
				{
					Label = "10";
					AMCL["Rin Duoctane"];
				},
				{
					Label = "11";
					AMCL["Sewer Pipe"];
					AMCL["Add On"];
				},
				{
					Label = "12";
					AMCL["Washed-up Mage"];
				},
			},
		},
	}, -- End of Dal Sewers

	-- Darnassus
	DN = {
	    ZoneName = { BabbleZone["Darnassus"].." ("..BabbleFaction["Alliance"].." - "..BabbleRace["Night Elf"]..")" };
	    Location = { BabbleZone["Teldrassil"] };

	    Areas = {
	    	-- Warrior's Terrace
			{
				Name = AMCL["Warrior's Terrace"];
				Color = WHITE;
				{
					Label = "D";
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
				},
				{
					Label = "1";
					AMCL["Mydrannul"];
					AMCL["Shylenai"];
					AMCL["Fyrenna"];
					AMCL["Ancient of War"];
					AMCL["Practice Dummy"];
				},
				{
					Label = "2";
					AMCL["Sildanair"];
					AMCL["Thyn'tel"];
				},
				{
					Label = "3";
					AMCL["Elanaria"];
					AMCL["Alliance Brigadier"];
					AMCL["Arias'ta"];
					AMCL["Darnath"];
					AMCL["Brogun"];
					AMCL["Enlae"];
					AMCL["Aethalas"];
					AMCL["Fima"];
					AMCL["Keras"];
					AMCL["Nivara"];
					AMCL["Nivara &"];
				},
				{
					Label = "4";
					AMCL["Ariyell"];
					AMCL["Mathiel"];
					AMCL["Forge"];
					AMCL["Cylania"];
					AMCL["Ilyenia"];
					PINK..""..AMCL["Bows"];
					PINK..""..AMCL["Fist Weapons"];
					PINK..""..AMCL["Staves"];
					PINK..""..AMCL["Thrown"];
					PINK..""..AMCL["Daggers"];
				}
			},
			-- Tradesmen's Terrace
			{
				Name = AMCL["Tradesmen's Terrace"];
				Color = PURP;
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "1";
					AMCL["General Goods & Bags"];
					AMCL["Ellandrieth"];
					AMCL["Yldan"];
				},
				{
					Label = "2";
					AMCL["Weapons"];
					AMCL["Glorandiir"];
					AMCL["Merelyssa"];
					AMCL["Mythidan"];
					AMCL["Kieran"];
				},
				{
					Label = "3";
					AMCL["Fletcher & Thrown Weapons"];
					AMCL["Landria"];
					AMCL["Turian"];
				},
				{
					Label = "4";
					AMCL["CAHW"];
					AMCL["Vinasia"];
					AMCL["Ealyshia D"];
					AMCL["Ealyshia D &"];
				},
				{
					Label = "5";
					AMCL["Leather Armor"];
					AMCL["Cyridan"];
				},
				{
					Label = "6";
					AMCL["Mail Armor & Shields"];
					AMCL["Melea"];
					AMCL["Caynrus"];
				},
				{
					Label = "7";
					AMCL["Jareth"];
				},
				{
					Label = "8";
					AMCL["Treshala"];
				},
				{
					Label = "9";
					AMCL["Sentinel's Bunkhouse"];
				},
				{
					Label = "10";
					AMCL["Staff & Robe"];
					AMCL["Andrus"];
					AMCL["Anadyia"];
				},
				{
					Label = "11";
					AMCL["Jaeana"];
					AMCL["Jaeana&"];
				}
			},
			-- Craftsmen's Terrace
			{
				Name = AMCL["Craftsmen's Terrace"];
				Color = YELL;
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["Saelienne"];
				},
				{
					Label = "1";
					AMCL["Guild"];
					AMCL["Lysheana"];
					AMCL["Shalumon"];
					AMCL["Ellaercia"];
				},
				{
					Label = "2";
					AMCL["Tailoring &"];
					AMCL["Me'lynn"];
					AMCL["Elynna"];
					AMCL["Raedon D"];
					AMCL["Raedon D &"];
					AMCL["Telonis"];
					AMCL["Saenorion"];
					AMCL["Eladriel"];
					AMCL["Lotherias"];
				},
				{
					Label = "3";
					AMCL["General"];
					AMCL["Mythrin'dir"];
				},
				{
					Label = "4";
					AMCL["Enchanting"];
					AMCL["Taladan"];
					AMCL["Vaean"];
					AMCL["Feyden D"];
					AMCL["Illianna M"];
				},
				{
					Label = "5";
					AMCL["Alchemy"];
					AMCL["Ainethil"];
					AMCL["Ulthir"];
					AMCL["Argent Guard Manados"];
					AMCL["D Selgorm"];
					AMCL["D Shaedlass"];
				},
				{
					Label = "6";
					AMCL["Cooking"];
					AMCL["Alegorn"];
					AMCL["Fyldan"];
					AMCL["Stove"];
				},
				{
					Label = "7";
					AMCL["First Aid"];
					AMCL["Dannelor"];
				}
			},
			-- Cenarion Enclave
			{
				Name = AMCL["Cenarion Enclave"];
				Color = BLUE;
				{
					Label = "T";
					AMCL["Tunnel R Trainer"];
				},
				{
					Label = "1";
					AMCL["Food & Drink"];
					AMCL["Dendrythis"];
				},
				{
					Label = "2";
					AMCL["Rellian G"];
				},
				{
					Label = "3";
					AMCL["Mounts"];
					AMCL["Jartsam"];
					AMCL["Lelanai"];
				},
				{
					Label = "4";
					AMCL["Hunter"];
					AMCL["Alassin"];
					AMCL["Jocaste"];
					AMCL["Corand"];
					AMCL["Jeen'ra N"];
					AMCL["Dorion"];
					AMCL["Silvaria"];
				},
				{
					Label = "5";
					AMCL["Druid"];
					AMCL["Denatharion"];
					AMCL["Fylerian N"];
					AMCL["Cyroen"];
					AMCL["Mathrengyl B"];
					AMCL["Fandral S"];
				},
				{
					Label = "6";
					AMCL["Poisons"];
					AMCL["Kyrai"];
					AMCL["Faelyssa"];
				},
				{
					Label = "7";
					AMCL["Rogue"];
					AMCL["Syurna"];
					AMCL["Anishar"];
					AMCL["Erion S"];
				}
			},
			-- The Temple Gardens
			{
				Name = AMCL["The Temple Gardens"];
				Color = GREN;
				{
					Label = "B";
					AMCL["Bank"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "P";
					AMCL["Portal to Rut'theran"];
				},
				{
					Label = "1";
					AMCL["O Lunalight"];
				},
				{
					Label = "2";
					AMCL["Sister Aquinne"];
				},
				{
					Label = "3";
					AMCL["Fishing"];
					AMCL["Astaia"];
					AMCL["Voloren"];
					AMCL["Talaelar"];
				},
				{
					Label = "4";
					AMCL["Herbalism"];
					AMCL["Firodren M"];
					AMCL["Chardryn"];
				},
				{
					Label = "5";
					AMCL["Greywhisker"];
					AMCL["Greywhisker &"];
				},
				{
					Label = "6";
					AMCL["Alaindia"];
					AMCL["Alaindia&"];
					AMCL["Alaindia&1"];
				}
			},
			-- Temple Moon
			{
				Name = AMCL["Temple Moon"];
				Color = CYAN;
				{
					Label = "1";
					AMCL["Main Floor"];
					AMCL["Jandria"];
					AMCL["Lariia"];
					AMCL["Elissa D"];
					AMCL["Dalia S"];
					AMCL["PorBlasted"];
				},
				{
					Label = "2";
					AMCL["Balconey"];
					AMCL["P A'moora"];
				},
				{
					Label = "3";
					AMCL["Balconey"];
					AMCL["AstariiS"];
					AMCL["PAlathea"];
					AMCL["TyrandeW"];
					AMCL["Valustraa"];
				},
				{
					Label = "4";
					AMCL["Balconey"];
					AMCL["Gracina S"];
				},
			},
		},
	}, -- End of Darnassus

	-- Exodar
	EX = {
	    ZoneName = { BabbleFaction["Exodar"].." ("..BabbleFaction["Alliance"].." - "..BabbleRace["Draenei"]..")" };
	    Location = { BabbleZone["Azuremyst Isle"] };

	    Areas = {
	    	-- Outside
			{
				Name = AMCL["Outside"];
				Color = YELL;
				{
					Label = "E";
					AMCL["Entrance Ex"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];

				},
				{
					Label = "2";
					AMCL["Stephanos"];
				},
				{
					Label = "3";
					AMCL["Torallius"];
					AMCL["Aalun"];
				}
			},

			-- Seat of the Naaru
			{
				Name = AMCL["Seat of the Naaru"];
				Color = GREN;
				{
					Label = "O";
					AMCL["Ancients Emissary"];
				},
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["Arthaid"];
					AMCL["Caregiver B"];
					AMCL["Miglik B"];
				},
				{
					Label = "B";
					AMCL["Bank"];
					AMCL["O Khaluun"];
				},
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["Mumman"];
					AMCL["Phea"];
					AMCL["CookP"];
				},
				{
					Label = "2";
					AMCL["Onnis"];
					AMCL["Cuzi"];
				},
				{
					Label = "3";
					AMCL["Bran'daan"];
				},
				{
					Label = "4";
					AMCL["Nurguni"];
				},
				{
					Label = "5";
					AMCL["O'ros"];
				}
			},

			-- Traders Tier
			{
				Name = AMCL["Traders Tier"];
				Color = _RED;
				{
					Label = "1";
					AMCL["Tailoring"];
					AMCL["Refik"];
					AMCL["Neii"];
					AMCL["Dugiru"];
				},
				{
					Label = "2";
					AMCL["Leatherworking and Skinning"];
					AMCL["Remere"];
					AMCL["Akham"];
					AMCL["Haferet"];
				},
				{
					Label = "3";
					AMCL["Plate Armor & Shields"];
					AMCL["Gotaan"];
					AMCL["Treall"];
				},
				{
					Label = "4";
					AMCL["Bladed Weapons"];
					AMCL["Ven"];
				},
				{
					Label = "5";
					AMCL["Blunt Weapons"];
					AMCL["Ellomin"];
				},
				{
					Label = "6";
					AMCL["Leather & Cloth Armor"];
					AMCL["Mahri"];
					AMCL["Gornii"];
				},
				{
					Label = "7";
					AMCL["Mail Armor"];
					AMCL["Yil"];
				},
				{
					Label = "8";
					AMCL["Mining and Smithing"];
					AMCL["Muaat"];
					AMCL["Merran"];
					AMCL["Miall"];
					AMCL["Arras"];
					AMCL["Forge"];
				},
				{
					Label = "9";
					AMCL["Engineering"];
					AMCL["Ockil"];
					AMCL["Feera"];
				},
				{
					Label = "10";
					AMCL["Hunters' Sanctum"];
					AMCL["Deremiis"];
					AMCL["Vord"];
					AMCL["Killac"];
					AMCL["Ganaar"];
					AMCL["Avelii"];
					AMCL["Muhaa"];
				},
				{
					Label = "11";
					AMCL["Ring of Arms"];
					AMCL["Fingin"];
					AMCL["Ahonan"];
					AMCL["Kazi"];
					AMCL["Behomat"];
					AMCL["Handiir"];
					PINK..""..AMCL["Daggers"];
					PINK..""..AMCL["Crossbow"];
					PINK..""..AMCL["One-Handed Sword"];
					PINK..""..AMCL["Two-Handed Sword"];
					PINK..""..AMCL["One-Handed Maces"];
					PINK..""..AMCL["Two-Handed Maces"];
				},
				{
					Label = "12";
					AMCL["Guild Master and Tabards"];
					AMCL["Funaam"];
					AMCL["Issca"];
				}
			},

			-- The Vault of Lights
			{
				Name = AMCL["The Vault of Lights"];
				Color = PURP;
				{
					Label = "O";
					AMCL["Ancients Emissary"];
				},
				{
					Label = "1";
					AMCL["Hall of the Mystics"];
					AMCL["Bati"];
					AMCL["Harnan"];
					AMCL["Edirah"];
					AMCL["Lunaraa"];
					AMCL["Oss"];
					AMCL["Musal"];
					AMCL["PorBlasted"];
				},
				{
					Label = "2";
					AMCL["Vindicators' Sanctum"];
					AMCL["Kavaan"];
					AMCL["Jol"];
					AMCL["Baatun"];
				},
				{
					Label = "3";
					AMCL["Alchemy and Herbalism"];
					AMCL["Lucc"];
					AMCL["Altaa"];
					AMCL["Cemmorhan"];
				},
				{
					Label = "4";
					AMCL["Tolo"];
					AMCL["Alliance Brigadier"];
				},
				{
					Label = "5";
					AMCL["Mahul"];
					AMCL["Mitia"];
				},
				{
					Label = "6";
					AMCL["Jihi"];
					AMCL["Buhurda"];
				},
				{
					Label = "7";
					AMCL["Prophet Velen"];
				},
				{
					Label = "8";
					AMCL["Anchorites' Sanctum"];
					AMCL["Izmir"];
					AMCL["Fallat"];
					AMCL["Caedmos"];
				}
			},
			-- The Crystal Hall
			{
				Name = AMCL["The Crystal Hall"];
				Color = WHITE;
				{
					Label = "D";
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
				},
				{
					Label = "1";
					AMCL["Enchanting"];
					AMCL["Nahogg"];
					AMCL["Egomis"];
					AMCL["Thoth"];
					AMCL["Sessoh"];
				},
				{
					Label = "2";
					AMCL["Sixx"];
				},
				{
					Label = "3";
					AMCL["Gurrag"];
				},
				{
					Label = "4";
					AMCL["F Nobundo"];
					AMCL["F Dunaer"];
					AMCL["Valon"];
				},
				{
					Label = "5";
					AMCL["Sulaa"];
				},
				{
					Label = "6";
					AMCL["Fishing"];
					AMCL["Erett"];
					AMCL["Dekin"];
				},
				{
					Label = "7";
					AMCL["Hobahken"];
				},
				{
					Label = "8";
					AMCL["Reagents"];
					AMCL["Bildine"];
				},
				{
					Label = "9";
					AMCL["First Aid"];
					AMCL["Nus"];
				},
				{
					Label = "10";
					AMCL["Jewelcrafting"];
					AMCL["Farii"];
					AMCL["Arred"];
					AMCL["Padaar"];
				},
				{
					Label = "11";
					AMCL["Seer Skaltesh"];
				},
			},
		},
	}, -- End of Exodar

	-- Ironforge	  
	IF = {
	    ZoneName = { BabbleZone["Ironforge"].." ("..BabbleFaction["Alliance"].." - "..BabbleRace["Dwarf"]..")" };
	    Location = { BabbleZone["Dun Morogh"] };

	    Areas = {
	    	-- The Common
			{
				Name = AMCL["The Common"];
				Color = WHITE;
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "B";
					AMCL["Bank"];
					AMCL["Dinita S"];
					AMCL["Lieutenant Rot"];
					AMCL["Lieutenant Rot &"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];

				},
				{
					Label = "1";
					AMCL["Barim"];
					AMCL["Barim J"];
				},
				{
					Label = "2";
					AMCL["Stonefire Tavern"];
					AMCL["Innkeeper Firebrew"];
					AMCL["Gwenna F"];
					AMCL["Larkin T"];
					AMCL["Brew Vendor"];
					AMCL["Sheldonore"];
				},
				{
					Label = "3";
					AMCL["Bshop"];
					AMCL["Pella B"];
				},
				{
					Label = "4";
					AMCL["Ironforge Armory"];
					AMCL["Mangorn F"];
					AMCL["Raena F"];
					AMCL["Bromiir O"];
				},
				{
					Label = "5";
					AMCL["Steelfury's Weapon Emporium"];
					AMCL["Dolman S"];
					AMCL["Grenil S"];
				},
				{
					Label = "6";
					AMCL["Fizzlespinner"];
					AMCL["Fillius F"];
					AMCL["Bryllia I"];
				},
				{
					Label = "7";
					AMCL["Marblesten"];
					AMCL["Marblesten&"];
				},
				{
					Label = "8";
					AMCL["Ironforge V C"];
					AMCL["Jondor S"];
					AMCL["Lyesa S"];
				},
				{
					Label = "9";
					AMCL["Myra T"];
					AMCL["Myra T &"];
				}
			},

			-- Mystic Ward
			{
				Name = AMCL["Mystic Ward"];
				Color = GREN;
				{
					Label = "O";
					AMCL["Ancients Emissary"];
				},
				{
					Label = "1";
					AMCL["Fighting Wizard"];
					AMCL["Bingus"];
					AMCL["Harick B"];
				},
				{
					Label = "2";
					AMCL["Hall of Mysteries"];
					AMCL["Toldren D"];
					AMCL["Braenna F"];
					AMCL["High Priest Rohan"];
					AMCL["Bink"];
					AMCL["Dink"];
					AMCL["Juli S"];
					AMCL["Milstaff S"];
					AMCL["Brandur I"];
					AMCL["Beldruk D"];
					AMCL["Theodrus F"];
					AMCL["Muiredon B"];
					AMCL["Valgar H"];
					AMCL["Nittlebur S"];
					AMCL["Tiza B"];
					AMCL["PorBlasted"];
				},
				{
					Label = "3";
					AMCL["Mage Tymor"];
				},
				{
					Label = "4";
					AMCL["Talvash Kissel"];
				},
				{
					Label = "5";
					AMCL["Maeva's"];
					AMCL["Maeva"];
					AMCL["Ingrys S"];
				},
				{
					Label = "6";
					AMCL["Longberry's"];
					AMCL["Ginny L"];
				},
				{
					Label = "7";
					AMCL["Bimble L"];
					AMCL["Bimble L&"];
				}
			},

			-- Forlorn Cavern
			{
				Name = AMCL["Forlorn Cavern"];
				Color = BLUE;
				{
					Label = "1";
					AMCL["Stoneblades"];
					AMCL["Hjoldir S"];
					AMCL["Binny"];
					AMCL["Prynne"];
				},
				{
					Label = "2";
					AMCL["Traveling Fisherman"];
					AMCL["Grimnur S"];
					AMCL["Tansy P"];
				},
				{
					Label = "3";
					AMCL["Lago B"];
				},
				{
					Label = "4";
					AMCL["Thistleheart"];
					AMCL["Briarthorn"];
					AMCL["Alexander C"];
					AMCL["Gerrig B"];
				},
				{
					Label = "5";
					AMCL["Tynnus V"];
					AMCL["Fenthwick"];
					AMCL["Ormyr F"];
					AMCL["Hulfdan B"];
					AMCL["Durtham G"];
				},
				{
					Label = "6";
					AMCL["Ransin D"];
					AMCL["Murky"];
				}
			},

			-- Hall of Explorers
			{
				Name = AMCL["Hall of Explorers"];
				Color = PURP;
				{
					Label = "1";
					AMCL["Roetten S"];
					AMCL["Magellas"];
				},
				{
					Label = "2";
					AMCL["The Library"];
					AMCL["Thorius"];
				},
				{
					Label = "3";
					AMCL["The Library"];
					AMCL["Lyon M"];
				},
				{
					Label = "4";
					AMCL["The Library"];
					AMCL["Laris G"];
				},
				{
					Label = "5";
					AMCL["The Library"];
					AMCL["Krom S"];
					AMCL["Prospector S"];
					AMCL["Mae P"];
					AMCL["Advisor B"];
					AMCL["Historian K"];
				}
			},

			-- Tinker Town
			{
				Name = AMCL["Tinker Town"];
				Color = CYAN;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["Bubulo"];
				},
				{
					Label = "2";
					AMCL["Boom!"];
					AMCL["Lomac"];
					AMCL["Fizzlebang"];
				},
				{
					Label = "3";
					AMCL["Berryfizz's"];
					AMCL["Tally B"];
					AMCL["Soolie B"];
				},
				{
					Label = "4";
					AMCL["Overspark"];
					AMCL["Overspark&"];
					AMCL["Gnoarn"];
				},
				{
					Label = "5";
					AMCL["Mekkatorque"];
				},
				{
					Label = "6";
					AMCL["Castpipe"];
					AMCL["Porterhouse"];
					AMCL["Porterhouse&"];
					AMCL["Klockmort"];
				},
				{
					Label = "7";
					AMCL["Springspindle's"];
					AMCL["Fizzlegear"];
					AMCL["Cogspinner"];
				},
				{
					Label = "8";
					AMCL["Deeprun Tram"];
					AMCL["Monty"];
					AMCL["Haggle"];
				}
			},

			-- The Military Ward
			{
				Name = AMCL["The Military Ward"];
				Color = ORNG;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "D";
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
				},
				{
					Label = "1";
					AMCL["Goldfury's"];
					AMCL["BrettaG"];
					AMCL["SkolminG"];
				},
				{
					Label = "2";
					AMCL["Bruuk's Corner"];
					AMCL["BruukB"];
					AMCL["TisaM"];
				},
				{
					Label = "3";
					AMCL["SognarC"];
					AMCL["SognarC&"];
				},
				{
					Label = "4";
					AMCL["Hall of Arms"];
					AMCL["UlbrekF"];
					AMCL["RegnusT"];
					AMCL["OlminB"];
					AMCL["BeliaT"];
					AMCL["DemnulF"];
					AMCL["DaeraB"];
					AMCL["KelvS"];
					AMCL["MaxX"];
					AMCL["DonalO"];
					AMCL["Lylandris"];
					AMCL["MargaB"];
					AMCL["MargaB&"];
					AMCL["Alliance Brigadier"];
					AMCL["GlordrumS"];
					AMCL["Kandaar"];
					AMCL["MurenS"];
					AMCL["KelstrumS"];
					AMCL["BilbanT"];
					AMCL["GilbartaG"];
					AMCL["PLongbeard"];
					AMCL["XiggsF"];
				},
				{
					Label = "5";
					AMCL["Timberline Arms"];
					AMCL["BuliwyfS"];
					PINK..""..AMCL["Fist Weapons"];
					PINK..""..AMCL["Guns"];
					PINK..""..AMCL["One-Handed Axes"];
					PINK..""..AMCL["Two-Handed Axes"];
					PINK..""..AMCL["Two-Handed Maces"];
					AMCL["BixiW"];
					PINK..""..AMCL["Crossbow"];
					PINK..""..AMCL["Daggers"];
					PINK..""..AMCL["Thrown"];
					AMCL["KelomirI"];
					AMCL["ThalgusT"];
					AMCL["HegnarS"];
					AMCL["BrenwynW"];
				},
				{
					Label = "6";
					AMCL["Craghelm's"];
					AMCL["LissyphusF"];
					AMCL["DolkinC"];
					AMCL["OlthranC"];
				},
				{
					Label = "7";
					AMCL["SaraB"];
				}
			},

			-- The Great Forge
			{
				Name = AMCL["The Great Forge"];
				Color = YELL;
				{
					Label = "1";
					AMCL["Ironforge Physician"];
					AMCL["ReynaS"];
					AMCL["GwinaS"];
					AMCL["NissaF"];
				},
				{
					Label = "2";
					AMCL["GrythT"];
				},
				{
					Label = "3";
					AMCL["Thistlefuzz Arcanery"];
					AMCL["EJademoon"];
					AMCL["GimbleT"];
					AMCL["TilliT"];
					AMCL["EliseB"];
					AMCL["ThargenH"];
				},
				{
					Label = "4";
					AMCL["Bronze Kettle"];
					AMCL["DarylR"];
					AMCL["EmrulR"];
					AMCL["Stove"];
					AMCL["DBcook"];
					AMCL["DBcook&"];
				},
				{
					Label = "5";
					AMCL["FJavad"];
				},
				{
					Label = "6";
					AMCL["DMMG"];
					AMCL["GeoframB"];
					AMCL["GolnirB"];
				},
				{
					Label = "7";
					AMCL["Burbik's"];
					AMCL["BurbikG"];
				},
				{
					Label = "8";
					AMCL["Stonebrow's"];
					AMCL["JormundS"];
					AMCL["PorannaS"];
					AMCL["OEric"];
					AMCL["MistinaS"];
					AMCL["MistinaS&"];
				},
				{
					Label = "9";
					AMCL["Finespindle's"];
					AMCL["FimbleF"];
					AMCL["BombusF"];
					AMCL["BalthusS"];
				},
				{
					Label = "10";
					AMCL["OIronbeard"];
				},
				{
					Label = "11";
					AMCL["Sraaz"];
					AMCL["Sraaz&"];
				},
				{
					Label = "12";
					AMCL["High Seat"];
					AMCL["KingMagni"];
					AMCL["SBarinR"];
					AMCL["RHArchesonus"];
					AMCL["Deliana"];
				},
				{
					Label = "13";
					AMCL["Great Forge"];
					AMCL["GrumnusS"];
					AMCL["IronusC"];
					AMCL["ThurgrumD"];
					AMCL["BengusD"];
					AMCL["MyolorS"];
					AMCL["BrombarH"];
					AMCL["TormusD"];
				},
			},
		},
	}, -- End of Ironforge

	-- Orgrimmar
	OG = {
	    ZoneName = { BabbleZone["Orgrimmar"].." ("..BabbleFaction["Horde"].." - "..BabbleRace["Orc"]..")" };
	    Location = { BabbleZone["Durotar"] };

	    Areas = {
	    	-- Valley Strength
			{
				Name = AMCL["Valley Strength"];
				Color = WHITE;
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "B";
					AMCL["Bank"];
					AMCL["FARokhs"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["Gryshka"];
					AMCL["Morag"];
					AMCL["Kozish"];
					AMCL["Sarok"];
					AMCL["Doyo'da"];
					AMCL["Zaro"];
					AMCL["Goma"];
					AMCL["Gamon"];
				},
				{
					Label = "1";
					AMCL["SLSA"];
					AMCL["Sana"];
					AMCL["Morgum"];
					AMCL["Ollanus"];
				},
				{
					Label = "2";
					AMCL["BImports"];
					AMCL["Kaja"];
				},
				{
					Label = "3";
					AMCL["SReagents"];
					AMCL["Horthus"];
				},
				{
					Label = "4";
					AMCL["Horde Embassy"];
					AMCL["Urtrun"];
					AMCL["Garyl"];
				},
				{
					Label = "5";
					AMCL["GenStore"];
					AMCL["Trak'gen"];
					AMCL["Shimra"];
				},
				{
					Label = "6";
					AMCL["ShattAxe"];
					AMCL["Urtharo"];
				},
				{
					Label = "7";
					AMCL["Chophouse"];
					AMCL["Olvia"];
					AMCL["OrcCook"];
					AMCL["OrcCook&"];
				},
				{
					Label = "8";
					AMCL["SlopeVS"];
				},
				{
					Label = "9";
					AMCL["Zankaja"];
					AMCL["MBlaze"];
				},
				{
					Label = "10";
					AMCL["Skytower"];
					AMCL["Doras"];
					AMCL["CEhoof"];
				},
				{
					Label = "11";
					AMCL["HallLegends"];
					AMCL["SGZarg"];
					AMCL["DorisV"];
					AMCL["BraveSton"];
					AMCL["BraveSton&"];
					AMCL["Zar'shi"];
					AMCL["LadyPal"];
					AMCL["SergThunder"];
					AMCL["SergThunder&"];
					AMCL["Bork"];
					AMCL["Hola'mahi"];
					AMCL["Earthbind"];
					AMCL["Willington"];
					AMCL["Teena"];
					AMCL["CArial"];
					AMCL["D'Anastasis"];
					AMCL["Hini'wana"];
					AMCL["Bek'rah"];
					AMCL["Korf"];
				},
				{
					Label = "12";
					AMCL["SkyStaves"];
					AMCL["Ukra'nor"];
				},
				{
					Label = "13";
					AMCL["Keldran"];
				},
				{
					Label = "14";
					AMCL["Xan'tish"];
					AMCL["Xan'tish&"];
				},
				{
					Label = "15";
					AMCL["Krixx"];
					AMCL["Krixx&"];
					AMCL["Krixx&1"];
					AMCL["Krixx&2"];
				}
			},

			-- ValleySpirits
			{
				Name = AMCL["ValleySpirits"];
				Color = PURP;
				{
					Label = "1";
					AMCL["DarkbriarL"];
					AMCL["Uthel'nay"];
					AMCL["Enyo"];
					AMCL["Deino"];
					AMCL["Pephredo"];
					AMCL["Thuul"];
					AMCL["Vehena"];
					AMCL["Ray'ma"];
					AMCL["Brew Vendor"];
					AMCL["PorBlasted"];
				},
				{
					Label = "2";
					AMCL["SpiLodge"];
					AMCL["Ur'kyo"];
					AMCL["X'yera"];
					AMCL["Zayus"];
				},
				{
					Label = "3";
					AMCL["SurvivalF"];
					AMCL["Arnok"];
				}
			},

			-- Drag
			{
				Name = AMCL["Drag"];
				Color = YELL;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["Borstan's"];
					AMCL["Borstan"];
					AMCL["Zamja"];
					AMCL["Xen'to"];
				},
				{
					Label = "2";
					AMCL["Jo'mah"];
					AMCL["Xantili"];
					AMCL["Zilzibin"];
					AMCL["Sarlek"];
					AMCL["Tamaro"];
				},
				{
					Label = "3";
					AMCL["Arboretum"];
					AMCL["Jandi"];
					AMCL["Zeal'aya"];
				},
				{
					Label = "4";
					AMCL["Runeworks"];
					AMCL["Jhag"];
					AMCL["Kithas"];
					AMCL["Slope1"];
				},
				{
					Label = "5";
					AMCL["Yelmak's"];
					AMCL["Yelmak"];
					AMCL["Kor'geld"];
					AMCL["Jes'rimon"];
				},
				{
					Label = "6";
					AMCL["Salvage"];
					AMCL["Dran"];
					AMCL["Malton"];
				},
				{
					Label = "7";
					AMCL["KLeatherworks"];
					AMCL["Karolek"];
					AMCL["Tamar"];
					AMCL["Thuwd"];
					AMCL["Handor"];
				},
				{
					Label = "8";
					AMCL["ClothG"];
					AMCL["Magar"];
					AMCL["Borya"];
					AMCL["Tor'phan"];
					AMCL["Rashona"];
					AMCL["Rashona&"];
				},
				{
					Label = "9";
					AMCL["Gotri's"];
					AMCL["Dran"];
				},
				{
					Label = "10";
					AMCL["Krixx2"];
					AMCL["Felika"];
					AMCL["Felika&"];
					AMCL["Felika&1"];
				}
			},

			-- ValleyHonor
			{
				Name = AMCL["ValleyHonor"];
				Color = BLUE;
				{
					Label = "F";
					AMCL["Forge"];
				},
				{
					Label = "D";
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
				},
				{
					Label = "1";
					AMCL["Kiro's"];
					AMCL["Kiro"];
				},
				{
					Label = "2";
					AMCL["OBowyer"];
					AMCL["Jin'sora"];
				},
				{
					Label = "3";
					AMCL["HallBrave"];
					AMCL["Zel'mak"];
					AMCL["Sorek"];
					AMCL["Grezz"];
					AMCL["Andrissa"];
					AMCL["Andrissa&"];
					AMCL["Deze"];
					AMCL["Zeggon"];
					AMCL["Brakgul"];
					AMCL["Brakgul&"];
					AMCL["Ufuda"];
					AMCL["Ufuda&"];
					AMCL["Kartra"];
					AMCL["Muja"];
					AMCL["HordeWar"];
					AMCL["BelgR"];
				},
				{
					Label = "4";
					AMCL["Lumak's"];
					AMCL["Lumak"];
					AMCL["Shankys"];
					AMCL["Zas'tysh"];
					AMCL["Murky"];
				},
				{
					Label = "5";
					AMCL["RedMining"];
					AMCL["Makaru"];
					AMCL["Gorina"];
				},
				{
					Label = "6";
					AMCL["Orphanage"];
				},
				{
					Label = "7";
					AMCL["Nogg's"];
					AMCL["Nogg"];
					AMCL["Roxxik"];
					AMCL["Sovik"];
					AMCL["Rilli"];
				},
				{
					Label = "8";
					AMCL["Shayis"];
					AMCL["Okothos"];
					AMCL["Borgosh"];
					AMCL["OxMO"];
					AMCL["Aturk"];
					AMCL["OrokkO"];
				},
				{
					Label = "9";
					AMCL["BurnAnvil"];
					AMCL["Saru"];
					AMCL["Sumi"];
					AMCL["Tumi"];
				},
				{
					Label = "10";
					AMCL["ArmsLegend"];
					AMCL["Kelgruk"];
					AMCL["Zendo'"];
					AMCL["Shoma"];
					AMCL["Galthuk"];
					AMCL["Sayoc"];
					PINK..""..AMCL["Bows"];
					PINK..""..AMCL["Daggers"];
					PINK..""..AMCL["Fist Weapons"];
					PINK..""..AMCL["Thrown"];
					PINK..""..AMCL["One-Handed Axes"];
					PINK..""..AMCL["Two-Handed Axes"];
					AMCL["Hanashi"];
					PINK..""..AMCL["Bows"];
					PINK..""..AMCL["Staves"];
					PINK..""..AMCL["Thrown"];
					PINK..""..AMCL["One-Handed Axes"];
					PINK..""..AMCL["Two-Handed Axes"];
					AMCL["Koru"];
				},
				{
					Label = "11";
					AMCL["RingValor"];
					AMCL["Molog"];
					AMCL["Greela"];
					AMCL["Greela&"];
				},
				{
					Label = "12";
					AMCL["Ogunaro"];
					AMCL["Kildar"];
					AMCL["Xon'cha"];
				},
				{
					Label = "13";
					AMCL["HuntHall"];
					AMCL["Sian'dur"];
					AMCL["Xor'juul"];
					AMCL["Ormak"];
				},
				{
					Label = "14";
					AMCL["Krixx2"];
				}
			},

			-- CleftShad
			{
				Name = AMCL["CleftShad"];
				Color = GREN;
				{
					Label = "1";
					AMCL["DarkEncl"];
					AMCL["Mirket"];
					AMCL["Zevrost"];
					AMCL["Grol'dar"];
					AMCL["Gan'rul"];
				},
				{
					Label = "2";
					AMCL["ShadReag"];
					AMCL["Hagrus"];
					AMCL["Cazul"];
				},
				{
					Label = "3";
					AMCL["ISW"];
					AMCL["Muragus"];
					AMCL["Katis"];
				},
				{
					Label = "4";
					AMCL["Neeru"];
				},
				{
					Label = "5";
					AMCL["RCI"];
				},
				{
					Label = "6";
					AMCL["DEFM"];
					AMCL["Kor'jus"];
				},
				{
					Label = "7";
					AMCL["Bshop"];
					AMCL["Berbri"];
				},
				{
					Label = "8";
					AMCL["SlowBlade"];
					AMCL["Kareth"];
				},
				{
					Label = "9";
					AMCL["ShadowBroth"];
					AMCL["Gest"];
					AMCL["Ormok"];
					AMCL["Shenthul"];
					AMCL["Zando'zan"];
					AMCL["Therzok"];
				},
				{
					Label = "10";
					AMCL["Rekkul's"];
					AMCL["Rekkul"];
					AMCL["Kor'ghan"];
				},
				{
					Label = "11";
					AMCL["Drok"];
					AMCL["Drok&"];
				}
			},

			-- ValleyWisdom
			{
				Name = AMCL["ValleyWisdom"];
				Color = CYAN;
				{
					Label = "1";
					AMCL["STVIF"];
					AMCL["Shan'ti"];
				},
				{
					Label = "2";
					AMCL["ORedblade"];
				},
				{
					Label = "3";
					AMCL["GromHold"];
					AMCL["Sian'tsu"];
					AMCL["Kardris"];
					AMCL["Sagorne"];
					AMCL["Zor"];
					AMCL["Searn"];
					AMCL["Eitrigg"];
					AMCL["Vol'jin"];
					AMCL["Mokvar"];
					AMCL["Pyreanor"];
					AMCL["Dawnsinger"];
					AMCL["Thrall"];
				},
				{
					Label = "4";
					AMCL["Asoran's"];
					AMCL["Asoran"];
					AMCL["Magenius"];
				},
				{
					Label = "5";
					AMCL["Vu'Shalay"];
				},
			},
		},
	}, -- End of Orgrimmar
	
	-- Shattrath  
	SR = {
	    ZoneName = { BabbleZone["Shattrath"].." ("..BabbleFaction["Neutral"]..")" };
	    Location = { BabbleZone["Terokkar Forest"] };

	    Areas = {
	    	-- TerLight
			{
				Name = AMCL["TerLight"];
				Color = WHITE;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "E";
					AMCL["LeagArat"];
					AMCL["Defil"];
				},
				{
					Label = "AB";
					AMCL["ABank"];
					AMCL["Endarin"];
					AMCL["ISaalyn"];
					AMCL["HaldorC"];
				},
				{
					Label = "SB";
					AMCL["SBank_Scryer"];
					AMCL["Enuril"];
					AMCL["IVeredis"];
					AMCL["Xorith"];
				},
				{
					Label = "1";
					AMCL["A'dal"];
					AMCL["Khadgar"];
					AMCL["Almonen"];
					AMCL["Tiras'alan"];
				},
				{
					Label = "2";
					AMCL["PorThBl"];
					AMCL["PorOrgr"];
					AMCL["PorUnde"];
					AMCL["Defil"];
				},
				{
					Label = "3";
					AMCL["Ontuvo"];
					AMCL["Ontuvo&"];
					AMCL["Almaador"];
					AMCL["Nasuun"];
					AMCL["PorQuel"];
					AMCL["Mehlisah"];
					AMCL["Anwehu"];
					AMCL["Anwehu&"];
					AMCL["G'eras"];
					AMCL["G'eras&"];
				},
				{
					Label = "4";
					AMCL["PorDarn"];
					AMCL["PorStor"];
					AMCL["PorIron"];
					AMCL["LeagArat"];
				},
				{
					Label = "5";
					AMCL["Iorioa"];
					AMCL["PorExod"];
					AMCL["PorSilv"];
					AMCL["V'eru"];
				},
				{
					Label = "6";
					AMCL["WarVet"];
					AMCL["LeagArat"];
					AMCL["Defil"];
				},
				{
					Label = "7";
					AMCL["Mordin"];
					AMCL["Torvos"];
				},
				{
					Label = "8";
					AMCL["Nutral"];
					AMCL["Yuula"];
				},
				{
					Label = "9";
					AMCL["Haronem"];
					AMCL["Wafflefry"];
				},
				{
					Label = "10";
					AMCL["LiftScry"];
				},
				{
					Label = "11";
					AMCL["LiftAR"];
				},
				{
					Label = "12";
					AMCL["WarVet"];
				},
				{
					Label = "13";
					AMCL["Ezekiel"];
					AMCL["Ezekiel&"];
				}
			},

			-- LowCity
			{
				Name = AMCL["LowCity"];
				Color = YELL;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["DLarry"];
					AMCL["EMalone"];
					AMCL["Creepjack"];
				},
				{
					Label = "2";
					AMCL["AldBank"];
					AMCL["LeagArat"];
					AMCL["Defil"];
				},
				{
					Label = "3";
					AMCL["Araac"];
				},
				{
					Label = "4";
					AMCL["Karokka"];
					AMCL["Skreah"];
					AMCL["Lorokeem"];
					AMCL["Vekax"];
				},
				{
					Label = "5";
					AMCL["Lissaf"];
				},
				{
					Label = "6";
					AMCL["RampL"];
					AMCL["Rilak"];
					AMCL["Adyria"];
					AMCL["LeagArat"];
					AMCL["DGrashna"];
				},
				{
					Label = "7";
					AMCL["Oloraak"];
				},
				{
					Label = "8";
					AMCL["ShattInf"];
					AMCL["Sha'nir"];
					AMCL["Seth"];
					AMCL["Zahlia"];
					AMCL["Rokk"];
					AMCL["Barth"];
				},
				{
					Label = "9";
					AMCL["ExitTF"];
					AMCL["LeagArat"];
					AMCL["Defil"];
				},
				{
					Label = "10";
					AMCL["RampL"];
					AMCL["ABG"];
					AMCL["ABG&"];
					AMCL["Vinvo"];
					AMCL["Vinvo&"];
					AMCL["Haelga"];
					AMCL["Lylandor"];
					AMCL["Iravar"];
					AMCL["AEternum"];
					AMCL["LeagArat"];
				},
				{
					Label = "11";
					AMCL["WorldEndT"];
					AMCL["Lathrai"];
					AMCL["Shaarubo"];
					AMCL["Lonika"];
					AMCL["Kylene"];
					AMCL["Pilton"];
					AMCL["Zhareem"];
					AMCL["Mah'duun"];
					AMCL["Zephyr"];
					AMCL["LeagArat"];
					AMCL["Defil"];
					AMCL["Raliq"];
					AMCL["salabim"];
				},
				{
					Label = "12";
					AMCL["ExitTF"];
					AMCL["LeagArat"];
					AMCL["Defil"];
					AMCL["WarVet"];
				},
				{
					Label = "13";
					AMCL["Kradu"];
					AMCL["Zula"];
					AMCL["Forge"];
				},
				{
					Label = "14";
					AMCL["Orph"];
					AMCL["Bartlett"];
				},
				{
					Label = "15";
					AMCL["HWB"];
					AMCL["Jojindi"];
					AMCL["Montok"];
					AMCL["Maka"];
					AMCL["Keldor"];
					AMCL["Yula"];
					AMCL["Defil"];
				},
				{
					Label = "16";
					AMCL["ExitTF"];
					AMCL["LeagArat"];
					AMCL["Defil"];
				},
				{
					Label = "17";
					AMCL["Seymour"];
					AMCL["Ernie"];
					AMCL["Cro"];
					AMCL["Darmari"];
					AMCL["Andrion"];
					AMCL["Gidge"];
					AMCL["Nasmara"];
					AMCL["Eiin"];
					AMCL["Griftah"];
					AMCL["Viggz"];
					AMCL["Fantei"];
					AMCL["Aaron"];
					AMCL["MRuby"];
					AMCL["Eral"];
					AMCL["Moser"];
					AMCL["Nakodu"];
					AMCL["JackT"];
					AMCL["Saltit"];
					AMCL["GSmith"];
					AMCL["BTurner"];
					AMCL["Grok"];
					AMCL["Oven"];
					AMCL["Tobias"];
					AMCL["Gordie"];
				},
				{
					Label = "18";
					AMCL["LowerSB"];
					AMCL["LeagArat"];
					AMCL["Defil"];
				},
				{
					Label = "19";
					AMCL["Browning"];
					AMCL["Browning&"];
				}
			},

			-- Scryer's Tier
			{
				Name = AMCL["Scryer's Tier"];
				Color = _RED;
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["Haelthol"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "F";
					AMCL["Forge"];

				},
				{
					Label = "1";
					AMCL["Ilthuril"];
					AMCL["Endernor"];
					AMCL["Lisrythe"];
					AMCL["Mahir"];
					AMCL["Dathris"];
				},
				{
					Label = "2";
					AMCL["Kirembri"];
					AMCL["Kirembri&"];
					AMCL["Hanlir"];
					AMCL["Lanloer"];
					AMCL["Andiala"];
				},
				{
					Label = "3";
					AMCL["Nalama"];
					AMCL["Urumir"];

				},
				{
					Label = "4";
					AMCL["Falris"];
					AMCL["Fyalenn"];
					AMCL["Fyalenn&"];

				},
				{
					Label = "5";
					AMCL["SeerLib"];
					AMCL["Arodis"];
					AMCL["Veynna"];
					AMCL["Volali"];
					AMCL["Bardolan"];
					AMCL["Bardolan&"];
					AMCL["Voren"];
					AMCL["Traini"];
					AMCL["Traini&"];

				},
				{
					Label = "6";
					AMCL["Mi'irku"];
					AMCL["Mi'irku&"];
					AMCL["Olodam"];

				},
				{
					Label = "7";
					AMCL["Alamaro"];
					AMCL["Amshesha"];
					AMCL["Yurial"];

				},
				{
					Label = "8";
					AMCL["Quelama"];
					AMCL["Selanam"];

				},
				{
					Label = "9";
					AMCL["Aelthin"];
					AMCL["Alaenra"];

				},
				{
					Label = "10";
					AMCL["Delvinar"];
					AMCL["Daenril"];
					AMCL["Miralisse"];
					AMCL["Irduil"];
					AMCL["Barien"];
					AMCL["Sinbei"];

				},
				{
					Label = "11";
					AMCL["LiftAR"];
				}
			},

			-- ARise
			{
				Name = AMCL["ARise"];
				Color = BLUE;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["Minalei"];
					AMCL["Garul"];
					AMCL["Oruhe"];
				},
				{
					Label = "1";
					AMCL["Nemiha"];
					AMCL["Fono"];
					AMCL["Zurii"];
					AMCL["Lidio"];
				},
				{
					Label = "2";
					AMCL["Adyen"];
					AMCL["Erothem"];
				},
				{
					Label = "3";
					AMCL["Caylee"];
				},
				{
					Label = "4";
					AMCL["Hamanar"];
					AMCL["Inessera"];
					AMCL["Ahemen"];
				},
				{
					Label = "5";
					AMCL["Dremm"];
					AMCL["Aoa"];
					AMCL["Korim"];
					AMCL["Bova"];
					AMCL["Kanhu"];
					AMCL["Jijia"];
					AMCL["Onodo"];
					AMCL["Mihila"];
				},
				{
					Label = "6";
					AMCL["UnenLight"];
					AMCL["Ishanah"];
					AMCL["Kelara"];
					AMCL["Asuur"];
				},
				{
					Label = "7";
					AMCL["ENagrand"];
				},
			},
		},
	}, -- End of Shattrath

	-- Silvermoon	  
	SM = {
	    ZoneName = { BabbleZone["Silvermoon City"].." ("..BabbleFaction["Horde"].." - "..BabbleRace["Blood Elf"]..")" };
	    Location = { BabbleZone["Eversong Woods"] };

	    Areas = {
	    	-- Bazaar
			{
				Name = AMCL["Bazaar"];
				Color = WHITE;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "B";
					AMCL["Bank"];
				},
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "I";
					AMCL["Wayfar"];
					AMCL["Jovia"];
					AMCL["Sylann"];
					AMCL["Quelis"];
					AMCL["Stove"];
				},
				{
					Label = "1";
					AMCL["SFinery"];
					AMCL["Zyandrel"];
					AMCL["Andra"];
					AMCL["Rathin"];
				},
				{
					Label = "2";
					AMCL["Bithrus"];
				},
				{
					Label = "3";
					AMCL["Keelen's"];
					AMCL["SorimL"];
					AMCL["Keelen"];
					AMCL["Deynna"];
				},
				{
					Label = "4";
					AMCL["Welethelon"];
					AMCL["Noraelath"];
				},
				{
					Label = "5";
					AMCL["BladesbR"];
					AMCL["Rahein"];
					AMCL["Feledis"];
				},
				{
					Label = "6";
					AMCL["GeGoods"];
					AMCL["Sathren"];
					AMCL["Zalle"];
				},
				{
					Label = "7";
					AMCL["SSPMP"];
					AMCL["Winthren"];
					AMCL["Tynna"];
					AMCL["Keeli"];
				},
				{
					Label = "8";
					AMCL["Parnis"];
				}
			},

			-- WElders
			{
				Name = AMCL["WElders"];
				Color = PURP;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "E";
					AMCL["Defil"];
				},
				{
					Label = "1";
					AMCL["Harene"];
				},
				{
					Label = "2";
					AMCL["Velaani's"];
					AMCL["Velanni"];
					AMCL["Zathanna"];
				},
				{
					Label = "3";
					AMCL["Wayfar"];
				},
				{
					Label = "4";
					AMCL["CGate"];
				},
				{
					Label = "5";
					AMCL["SilRegistry"];
					AMCL["Tandrine"];
					AMCL["Kredis"];
				},
				{
					Label = "6";
					AMCL["Lynalis"];
					AMCL["Zaralda"];
					AMCL["Tyn"];
				},
				{
					Label = "7";
					AMCL["Drathen"];
					AMCL["Olirea"];
					AMCL["Alestus"];
				}
			},

			-- RoyEx
			{
				Name = AMCL["RoyEx"];
				Color = GREN;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "B";
					AMCL["Bank"];
				},
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "I";
					AMCL["SCI"];
					AMCL["Velandra"];
					AMCL["Suntouched"];
					AMCL["BKAdept"];
					AMCL["Stillb"];
					AMCL["Stove"];

				},
				{
					Label = "1";
					AMCL["Kalinda"];
					AMCL["Gelanthis"];
					AMCL["Amin"];
				}
			},

			-- FarSquare
			{
				Name = AMCL["FarSquare"];
				Color = _RED;
				{
					Label = "E";
					AMCL["Defil"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "D";
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
				},
				{
					Label = "1";
					AMCL["Celana"];
					AMCL["Matha"];
				},
				{
					Label = "2";
					AMCL["Osselan"];
					AMCL["Ithelis"];
					AMCL["CBachi"];
					AMCL["Bvalor"];
					AMCL["Ileda"];
					PINK..""..AMCL["Bows"];
					PINK..""..AMCL["Daggers"];
					PINK..""..AMCL["Polearms"];
					PINK..""..AMCL["Thrown"];
					PINK..""..AMCL["One-Handed Sword"];
					PINK..""..AMCL["Two-Handed Sword"];
					AMCL["Astalor"];
					AMCL["Solanar"];
				},
				{
					Label = "3";
					AMCL["Bipp"];
					AMCL["Karen"];
					AMCL["Alenjon"];
					AMCL["Irissa"];
					AMCL["Caradess"];
--					AMCL["Gurak"];
--					AMCL["Duyash"];
--					AMCL["Krukk"];
--					AMCL["Mabrian"];
--					AMCL["Mabrian&"];
					AMCL["HordeWar"];
				},
				{
					Label = "4";
					AMCL["SLowerSec"];
				},
				{
					Label = "5";
					AMCL["Shalenn"];
					AMCL["Tana"];
					AMCL["Oninath"];
					AMCL["Zandine"];
					AMCL["Halthenis"];
				},
				{
					Label = "6";
					AMCL["Zelan"];
					AMCL["Belil"];
					AMCL["Bemarrin"];
					AMCL["Eriden"];
					AMCL["Forge"];
				},
				{
					Label = "7";
					AMCL["Danwe"];
					AMCL["Yatheon"];
					AMCL["Gloresse"];
				}
			},

			-- MurRow
			{
				Name = AMCL["MurRow"];
				Color = LTBLU;
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["Nerisen"];
					AMCL["Elara"];
					AMCL["Zelanis"];
					AMCL["Darlia"];
				},
				{
					Label = "2";
					AMCL["Talionia"];
					AMCL["Alamma"];
					AMCL["Zanien"];
				}
			},

			-- CourtSun
			{
				Name = AMCL["CourtSun"];
				Color = ORNG;
				{
					Label = "E";
					AMCL["Defil"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "1";
					AMCL["Sedana"];
					AMCL["Lyna"];
					AMCL["Dolothos"];
					AMCL["Zantasia"];
					AMCL["Lelorian"];
				},
				{
					Label = "2";
					AMCL["Camberon"];
					AMCL["Nathera"];
					AMCL["Melaris"];
					AMCL["Razia"];
				}
			},

			-- SunSpire
			{
				Name = AMCL["SunSpire"];
				Color = BLUE;
				{
					Label = "1";
					AMCL["OrbTrans"];
				},
				{
					Label = "2";
					AMCL["Lor'themar"];
					AMCL["Brightwing"];
					AMCL["Rommath"];
				},
				{
					Label = "3";
					AMCL["Lotheolan"];
					AMCL["Belestra"];
					AMCL["Aldrae"];
				},
				{
					Label = "4";
					AMCL["Zaedana"];
					AMCL["Quithas"];
					AMCL["Inethven"];
					AMCL["Narinth"];
					AMCL["Elrodan"];
					AMCL["Aurosalia"];
					AMCL["PorBlasted"];
				}
			},
		},
	}, -- End of Silvermoon

	-- Stormwind	 
	SW = {
	    ZoneName = { BabbleZone["Stormwind"].." ("..BabbleFaction["Alliance"].." - "..BabbleRace["Human"]..")" };
	    Location = { BabbleZone["Elwynn Forest"] };

	    Areas = {
	    	-- ValHer
			{
				Name = AMCL["ValHer"];
				Color = LTBLU;
				{
					Label = "1";
					AMCL["Jorgen"];
				},
				{
					Label = "2";
					AMCL["Umbrua"];
				},
				{
					Label = "3";
					AMCL["GMarcus"];
				},
				{
					Label = "4";
					AMCL["FMAfras"];
				},
				{
					Label = "5";
					AMCL["MMattin"];
				},
				{
					Label = "6";
					AMCL["Goodman"];
				}
			},

			-- TDistri
			{
				Name = AMCL["TDistri"];
				Color = WHITE;
				{
					Label = "B";
					AMCL["SBank"];
					AMCL["Mailbox"];
					AMCL["Maloof"];
				},
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "1";
					AMCL["SWVC"];
					AMCL["AldwinL"];
					AMCL["RebecL"];
				},
				{
					Label = "2";
					AMCL["Trias'C"];
					AMCL["ElaineT"];
					AMCL["BenT"];
					AMCL["ETrias"];
				},
				{
					Label = "3";
					AMCL["Pestle's"];
					AMCL["RenatG"];
					AMCL["KyraB"];
					AMCL["KeldrB"];
					AMCL["MPestl"];
				},
				{
					Label = "4";
					AMCL["EveryM"];
					AMCL["StephanT"];
					AMCL["EdnaM"];
					AMCL["TMull"];
				},
				{
					Label = "5";
					AMCL["Weller's"];
					AMCL["MardaW"];
					AMCL["GunthW"];
					AMCL["WooPing"];
					PINK..""..AMCL["Crossbow"];
					PINK..""..AMCL["Daggers"];
					PINK..""..AMCL["Polearms"];
					PINK..""..AMCL["Staves"];
					PINK..""..AMCL["One-Handed Sword"];
					PINK..""..AMCL["Two-Handed Sword"];
				},
				{
					Label = "6";
					AMCL["LionArm"];
					AMCL["CarlaG"];
					AMCL["LaraM"];
					AMCL["AldrM"];
					AMCL["HarlB"];
				},
				{
					Label = "7";
					AMCL["TGRI"];
					AMCL["InnAl"];
				},
				{
					Label = "8";
					AMCL["EmpQuiv"];
					AMCL["FredeS"];
					AMCL["LinaS"];
				},
				{
					Label = "9";
					AMCL["Bshop"];
					AMCL["JSharp"];
				},
				{
					Label = "10";
					AMCL["DungL"];
				},
				{
					Label = "11";
					AMCL["FragFlow"];
					AMCL["BGump"];
					AMCL["FGump"];
				},
				{
					Label = "12";
					AMCL["CanalTail"];
					AMCL["LisbS"];
					AMCL["RemaS"];
				},
				{
					Label = "13";
					AMCL["ArnoL"];
					AMCL["CatheL"];
				},
				{
					Label = "14";
					AMCL["GallWine"];
					AMCL["JuliG"];
					AMCL["RobertP"];
					AMCL["SuzetG"];
				}
			},

			-- MageQuart
			{
				Name = AMCL["MageQuart"];
				Color = ORNG;
				{
					Label = "1";
					AMCL["Stock"];
					AMCL["WThelw"];
					AMCL["Stocks"];
				},
				{
					Label = "2";
					AMCL["CStanf"];
					AMCL["McCorm"];
				},
				{
					Label = "3";
					AMCL["Mazen"];
					AMCL["Mazen&"];
					AMCL["AdairG"];
					AMCL["ADellis"];
				},
				{
					Label = "4";
					AMCL["LucanC"];
					AMCL["JessaraC"];
				},
				{
					Label = "5";
					AMCL["SWStaves"];
					AMCL["ArdwynC"];
					AMCL["AllanH"];
				},
				{
					Label = "6";
					AMCL["Duncan'sT"];
					AMCL["DuncanC"];
					AMCL["AlexanB"];
					AMCL["GeorgB"];
					AMCL["Clavicus"];
					AMCL["Clavicus&"];
				},
				{
					Label = "7";
					AMCL["AlcNee"];
					AMCL["Tannysa"];
					AMCL["Lilyss"];
					AMCL["MariaL"];
					AMCL["Eldra"];
				},
				{
					Label = "8";
					AMCL["CollinM"];
				},
				{
					Label = "9";
					AMCL["BlueRec"];
					AMCL["Joachim"];
					AMCL["ConnorR"];
					AMCL["SLohan"];
					AMCL["AStern"];
					AMCL["Mailbox"];
					AMCL["CFire"];
				},
				{
					Label = "10";
					AMCL["AMalin"];
				},
				{
					Label = "11";
					AMCL["WizSan"];
					AMCL["HAndromath"];
					AMCL["JCannon"];
					AMCL["Elsharin"];
					AMCL["MDumas"];
					AMCL["LPurdue"];
				},
				{
					Label = "12";
					AMCL["LarsonClo"];
					AMCL["WLarson"];
					AMCL["ELarson"];
				},
				{
					Label = "13";
					AMCL["EssenComp"];
					AMCL["OVaughn"];
				},
				{
					Label = "14";
					AMCL["AncientCu"];
					AMCL["Yserian"];
				},
				{
					Label = "15";
					AMCL["SlaughtLa"];
					AMCL["Jarel"];
					AMCL["Jalane"];
					AMCL["Zardeth"];
					AMCL["Sandahl"];
					AMCL["Gakin"];
					AMCL["Cloyce"];
					AMCL["Deline"];
					AMCL["Spackle"];
				},
				{
					Label = "16";
					AMCL["Pyrot"];
					AMCL["Singh"];
				}
			},

			-- SWPark
			{
				Name = AMCL["SWPark"];
				Color = CYAN;
				{
					Label = "1";
					AMCL["Folsom"];
				},
				{
					Label = "2";
					AMCL["Sylista"];
				},
				{
					Label = "3";
					AMCL["SWInn"];
				},
				{
					Label = "4";
					AMCL["Shylamiir"];
				},
				{
					Label = "5";
					AMCL["Tavern"];
					AMCL["Mailbox"];
					AMCL["CFire"];
				},
				{
					Label = "6";
					AMCL["ArgosN"];
					AMCL["Sheldras"];
					AMCL["Theridran"];
					AMCL["Maldryn"];
					AMCL["NaraM"];
				},
				{
					Label = "7";
					AMCL["WAP"];
					AMCL["Shailiea"];
					AMCL["KimberG"];
					AMCL["KellyG"];
				}
			},

			-- SWHarbor
			{
				Name = AMCL["SWHarbor"];
				Color = _RED;
				{
					Label = "1";
					AMCL["Thargold"];
				},
				{
					Label = "2";
					AMCL["Nayura"];
					AMCL["SAuberd"];
				},
				{
					Label = "3";
					AMCL["Assurance"];
					AMCL["PCarver"];
					AMCL["GCPK"];
					AMCL["kurtisP"];
				},
				{
					Label = "4";
					AMCL["LeeshaT"];
					AMCL["SVali"];
				},
				{
					Label = "5";
					AMCL["StevenA"];
				},
				{
					Label = "6";
					AMCL["SWlight"];
				}
			},

			-- CathSqua
			{
				Name = AMCL["CathSqua"];
				Color = PURP;
				{
					Label = "1";
					AMCL["MorrisL"];
				},
				{
					Label = "2";
					AMCL["FThread"];
				},
				{
					Label = "3";
					AMCL["JMaces"];
					AMCL["GArdus"];
				},
				{
					Label = "4";
					AMCL["RPlates"];
					AMCL["AgustM"];
					AMCL["TheresM"];
				},
				{
					Label = "5";
					AMCL["BKrist"];
				},
				{
					Label = "6";
					AMCL["Orphanage"];
					AMCL["OMNight"];
					AMCL["Shel"];
				},
				{
					Label = "7";
					AMCL["CathLig"];
					AMCL["BSarno"];
					AMCL["Rall"];
					AMCL["BFarth"];
					AMCL["ABBened"];
					AMCL["Gazin"];
					AMCL["HPLaur"];
					AMCL["JoshPT"];
					AMCL["Benj"];
				},
				{
					Label = "8";
					AMCL["CathLig"];
					AMCL["Grayson"];
					AMCL["KathPT"];
					AMCL["ArthPT"];
				},
				{
					Label = "9";
					AMCL["CathLig"];
					AMCL["SFull"];
					AMCL["BCass"];
				},
				{
					Label = "10";
					AMCL["CathLigD"];
					AMCL["BAnton"];
				},
				{
					Label = "11";
					AMCL["CityHall"];
					AMCL["BarosA"];
					AMCL["RFBathr"];
				},
				{
					Label = "12";
					AMCL["ArgentD"];
				},
				{
					Label = "13";
					AMCL["OEmma"];
					AMCL["OEmma&"];
				}
			},

			-- DwarvDist
			{
				Name = AMCL["DwarvDist"];
				Color = YELL;
				{
					Label = "1";
					AMCL["CTAlley"];
				},
				{
					Label = "2";
					AMCL["GelmanS"];
					AMCL["BrookeS"];
				},
				{
					Label = "3";
					AMCL["BorgusS"];
					AMCL["KathA"];
					AMCL["Grimand"];
				},
				{
					Label = "4";
					AMCL["ThulmF"];
				},
				{
					Label = "5";
					AMCL["Shoni"];
				},
				{
					Label = "6";
					AMCL["LilliS"];
					AMCL["BilliC"];
				},
				{
					Label = "7";
					AMCL["Deeprun Tram"];
					AMCL["EyeStorm"];
				},
				{
					Label = "8";
					AMCL["TherumD"];
					AMCL["KaitaD"];
					AMCL["Hank"];
					AMCL["Furen"];
					AMCL["BenikB"];
				},
				{
					Label = "9";
					AMCL["Jenova"];
					AMCL["Einris"];
					AMCL["Ulfir"];
					AMCL["Thorfin"];
				},
				{
					Label = "10";
					AMCL["Morgg"];
				},
				{
					Label = "11";
					AMCL["Tavern"];
					AMCL["Brohann"];
					AMCL["Wilder"];
				}
			},

			-- SWKeep
			{
				Name = AMCL["SWKeep"];
				Color = BLUE;
				{
					Label = "1";
					AMCL["PetCham"];
					AMCL["CRRidge"];
					AMCL["LBWishock"];
					AMCL["Caledra"];
				},
				{
					Label = "2";
					AMCL["Varian"];
					AMCL["Anduin"];
					AMCL["ETaluun"];
				},
				{
					Label = "3";
					AMCL["Delavey"];
				},
				{
					Label = "4";
					AMCL["WarRoom"];
					AMCL["Jes-Ter"];
					AMCL["MithI"];
					AMCL["Alliance Brigadier"];
					AMCL["EyeStorm"];
					AMCL["Beka"];
					AMCL["ThelmS"];
					AMCL["Elfarran"];
					AMCL["Jovil"];
					AMCL["Hotes"];
					AMCL["Bethany"];
				},
				{
					Label = "5";
					AMCL["MSamuel"];
				},
				{
					Label = "6";
					AMCL["Tyrion"];
					AMCL["Alicia"];
				},
				{
					Label = "7";
					AMCL["RoyLib"];
					AMCL["Milton"];
					AMCL["Donyal"];
					AMCL["GregorL"];
				},
				{
					Label = "8";
					AMCL["RoyGal"];
				}
			},

			-- OldTown
			{
				Name = AMCL["OldTown"];
				Color = GREN;
				{
					Label = "1";
					AMCL["HHW"];
					AMCL["GKoen"];
				},
				{
					Label = "2";
					AMCL["Pig&W"];
					AMCL["Mailbox"];
					AMCL["ReeseL"];
					AMCL["SRyback"];
					AMCL["ETate"];
					AMCL["KKabon"];
					AMCL["Bartleby"];
					AMCL["DLangs"];
					AMCL["Aedis"];
					AMCL["Faral"];
					AMCL["HarryB"];
					AMCL["EllyLang"];
				},
				{
					Label = "3";
					AMCL["FDV"];
					AMCL["Lenney"];
					AMCL["Beasley"];
					AMCL["Dashel"];
					AMCL["MilesS"];
					AMCL["Wright"];
				},
				{
					Label = "4";
					AMCL["HonestB"];
					AMCL["Heinrich"];
				},
				{
					Label = "5";
					AMCL["Immuni"];
					AMCL["OStrang"];
					AMCL["WStrang"];
				},
				{
					Label = "6";
					AMCL["Osborne"];
				},
				{
					Label = "7";
					AMCL["CHall"];
					AMCL["O'Neal"];
					AMCL["Jacksp"];
					AMCL["Biggin"];
					AMCL["Biggin&"];
					AMCL["Karter"];
					AMCL["Tristia"];
					AMCL["Skyshad"];
					AMCL["Ennarth"];
					AMCL["Gaiman"];
					AMCL["Vaccar"];
					AMCL["Dirgeh"];
					AMCL["Dirgeh&"];
					AMCL["Moonst"];
					AMCL["Moonst&"];
					AMCL["Clate"];
				},
				{
					Label = "8";
					AMCL["ComCent"];
					AMCL["G Dummy"];
					AMCL["Wood"];
					AMCL["IlsaC"];
					AMCL["WuShen"];
					AMCL["AnderG"];
				},
				{
					Label = "9";
					AMCL["SI:7"];
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
					AMCL["Mathias"];
					AMCL["Renzik"];
					AMCL["Sloan"];
					AMCL["Fel"];
					AMCL["Romano"];
					AMCL["Mixil"];
				},
				{
					Label = "10";
					AMCL["ProHide"];
					AMCL["STanner"];
					AMCL["JTanner"];
					AMCL["Granger"];
					AMCL["AlyssaG"];
					AMCL["SeomanG"];
					AMCL["Noah"];
				},
				{
					Label = "11";
					AMCL["ThanBoo"];
					AMCL["Mayda"];
				},
				{
					Label = "12";
					AMCL["SilverSh"];
					AMCL["BCross"];
				},
				{
					Label = "13";
					AMCL["JennL"];
					AMCL["Nikova"];
					AMCL["Nikova&"];
					AMCL["Nikova&1"];
				},
			},
		},
	}, -- End of Stormwind

	-- Thunder Bluff	 
	TB = {
	    ZoneName = { BabbleZone["Thunder Bluff"].." ("..BabbleFaction["Horde"].." - "..BabbleRace["Tauren"]..")" };
	    Location = { BabbleZone["Mulgore"] };

	    Areas = {
	    	-- LLevel
			{
				Name = AMCL["LLevel"];
				Color = WHITE;
				{
					Label = "AH";
					AMCL["AH"];
				},
				{
					Label = "M";
					AMCL["Mailbox"];
				},
				{
					Label = "B";
					AMCL["Bank"];
				},
				{
					Label = "L";
					AMCL["ElevM"];
				},
				{
					Label = "E";
					AMCL["EyeStorm"];
				},
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["Pala"];
					AMCL["Bulrug"];
					AMCL["AtHR"];
				},
				{
					Label = "1";
					AMCL["TBCI"];
					AMCL["Thrumn"];
					AMCL["Krumn"];
					AMCL["Scorch"];
				},
				{
					Label = "2";
					AMCL["Kuruk's"];
					AMCL["Kuruk"];
					AMCL["Pakwa"];
				},
				{
					Label = "3";
					AMCL["TGASu"];
					AMCL["ShadiM"];
				},
				{
					Label = "4";
					AMCL["Jyn"];
					AMCL["Ansek"];
					PINK..""..AMCL["Guns"];
					PINK..""..AMCL["Staves"];
					PINK..""..AMCL["One-Handed Maces"];
					PINK..""..AMCL["Two-Handed Maces"];
				},
				{
					Label = "5";
					AMCL["Hewa's"];
					AMCL["Hewa"];
					AMCL["Elki"];
					AMCL["Ahanu"];
				},
				{
					Label = "6";
					AMCL["Tal"];
					AMCL["ALLMLUL"];
					AMCL["ALLMLUL&"];
				},
				{
					Label = "7";
					AMCL["derstr"];
					AMCL["derstr&"];
				},
				{
					Label = "8";
					AMCL["BandG"];
					AMCL["Fry"];
				},
				{
					Label = "9";
					AMCL["Karn's"];
					AMCL["Karn"];
					AMCL["Taur"];
					AMCL["Orm"];
					AMCL["Forge"];
				},
				{
					Label = "10";
					AMCL["Truths"];
					AMCL["AtSR"];
				},
				{
					Label = "11";
					AMCL["Geology"];
					AMCL["Brek"];
					AMCL["KurmS"];
				},
				{
					Label = "12";
					AMCL["Eyahn"];
					AMCL["Auld"];
				},
				{
					Label = "13";
					AMCL["Chepi"];
					AMCL["Chepi&"];
					AMCL["Windst"];
					AMCL["Windst&"];
				}
			},

			-- MLevel
			{
				Name = AMCL["MLevel"];
				Color = PURP;
				{
					Label = "L";
					AMCL["ElevM"];
				},
				{
					Label = "E";
					AMCL["EyeStorm"];
				},
				{
					Label = "1";
					AMCL["Thund"];
					AMCL["Kuna"];
				},
				{
					Label = "2";
					AMCL["FaV"];
					AMCL["Nan"];
				},
				{
					Label = "3";
					AMCL["Holis"];
					AMCL["Komin"];
					AMCL["Nida"];
				},
				{
					Label = "4";
					AMCL["AtER"];
				},
				{
					Label = "5";
					AMCL["CloudB"];
					AMCL["Tand"];
				},
				{
					Label = "6";
					AMCL["Bena's"];
					AMCL["Bena"];
					AMCL["Mani"];
				},
				{
					Label = "7";
					AMCL["TBEnchanters"];
					AMCL["Teg"];
					AMCL["Nata"];
				},
				{
					Label = "8";
					AMCL["AtSR"];
				},
				{
					Label = "9";
					AMCL["TBArmorers"];
					AMCL["Mooranta"];
					AMCL["Veren"];
					AMCL["Tepa"];
					AMCL["Mahu"];
					AMCL["Tagain"];
					AMCL["Fela"];
					AMCL["Grod"];
					AMCL["Una"];
					AMCL["Rumstag"];
					AMCL["Rumstag&"];
				}
			},

			-- ULevel
			{
				Name = AMCL["ULevel"];
				Color = YELL;
				{
					Label = "1";
					AMCL["Rainsticks"];
					AMCL["Sunn"];
				},
				{
					Label = "2";
					AMCL["KS&R"];
					AMCL["Kaga"];
				},
				{
					Label = "3";
					AMCL["WinterT"];
					AMCL["Tah"];
				},
				{
					Label = "4";
					AMCL["MTB&T"];
					AMCL["Kah"];
					AMCL["Sewa"];
				},
				{
					Label = "5";
					AMCL["AtER"];
				},
				{
					Label = "6";
					AMCL["CairneB"];
				},
				{
					Label = "7";
					AMCL["Halpa"];
				},
				{
					Label = "8";
					AMCL["AtHR"];
				},
				{
					Label = "9";
					AMCL["TBFirea"];
					AMCL["Hogor"];
				},
				{
					Label = "10";
					AMCL["Raget"];
					AMCL["Delgo"];
					AMCL["Etu"];
					AMCL["Ohanko"];
					AMCL["Kard"];
				},
				{
					Label = "11";
					AMCL["Sura"];
				},
				{
					Label = "12";
					AMCL["Aska's"];
					AMCL["Aska"];
					AMCL["Naal"];
				},
				{
					Label = "13";
					AMCL["Zangen"];
				}
			},

			-- HuntR
			{
				Name = AMCL["HuntR"];
				Color = BLUE;
				{
					Label = "D";
					AMCL["E Dummy"];
					AMCL["M Dummy"];
					AMCL["G Dummy"];
					AMCL["H Dummy"];
				},
				{
					Label = "1";
					AMCL["HHall"];
					AMCL["Urek"];
					AMCL["Kary"];
					AMCL["Holt"];
					AMCL["Sark"];
					AMCL["Torm"];
					AMCL["Ker"];
				},
				{
					Label = "2";
					AMCL["Saern"];
					AMCL["Melor"];
				},
				{
					Label = "3";
					AMCL["Althal"];
					AMCL["Martin"];
					AMCL["Fizim"];
				},
				{
					Label = "4";
					AMCL["Kergul"];
					AMCL["Taim"];
					AMCL["Ufuda"];
					AMCL["Ufuda&"];
				},
				{
					Label = "5";
					AMCL["Mosarn"];
				},
				{
					Label = "6";
					AMCL["Hesuwa"];
				}
			},

			-- ERise
			{
				Name = AMCL["ERise"];
				Color = GREN;
				{
					Label = "1";
					AMCL["HElders"];
					AMCL["Kym"];
					AMCL["Turak"];
					AMCL["Sheal"];
					AMCL["Nara"];
					AMCL["ADHamuul"];
				},
				{
					Label = "2";
					AMCL["Bashana"];
				},
				{
					Label = "3";
					AMCL["Rahuro"];
					AMCL["Magatha"];
					AMCL["Cor"];
					AMCL["Gorm"];
				},
				{
					Label = "4";
					AMCL["ERDrums"];
					AMCL["Sheza"];
				},
				{
					Label = "5";
					AMCL["Ghede"];
				}
			},

			-- Spirit Rise
			{
				Name = AMCL["SRise"];
				Color = ORNG;
				{
					Label = "1";
					AMCL["HallofS"];
					AMCL["Beram"];
					AMCL["Siln"];
					AMCL["Tigor"];
					AMCL["Xanis"];
				},
				{
					Label = "2";
					AMCL["SHealing"];
					AMCL["Pand"];
				},
				{
					Label = "3";
					AMCL["Pawe"];
				},
				{
					Label = "4";
					AMCL["PVision"];
					AMCL["Clarice"];
					AMCL["Poshken"];
					AMCL["Mertle"];
					AMCL["Malakai"];
					AMCL["Zamah"];
					AMCL["Cranst"];
					AMCL["Shymm"];
					AMCL["Welsh"];
					AMCL["Ursyn"];
					AMCL["FCobb"];
					AMCL["Xane"];
					AMCL["PorBlasted"];
				},
			},
		},
	}, -- End of Thunder Bluff
	 
	-- Undercity
	UC = {
	    ZoneName = { BabbleZone["Undercity"].." ("..BabbleFaction["Horde"].." - "..BabbleRace["Undead"]..")" };
	    Location = { BabbleZone["Tirisfal Glades"] };

	    Areas = {
	    		-- Ruins of Lordaeron, outdoor
	    		{
	    			Name = BabbleZone["Ruins of Lordaeron"];
	    			Color = YELL;
	    			{
	    				Label = "A";
	    				AMCL["PorSilv"];
	    			}
	    		},
	    		
	    		-- Trade Quarter
			{
				Name = AMCL["TraQuart"];
				Color = WHITE;
				{
					Label = "B";
					AMCL["Bank"];

				},
				{
					Label = "A";
					AMCL["Aucti"];
					AMCL["Aucti&"];

				},
				{
					Label = "I";
					AMCL["Inn"];
					AMCL["INorman"];
					AMCL["AMaulray"];
					AMCL["Mailbox"];

				},
				{
					Label = "1";
					AMCL["GenGoods"];
					AMCL["ERusk"];
				},
				{
					Label = "2";
					AMCL["GenGoods"];
					AMCL["FDoan"];
					AMCL["GCallow"];
				},
				{
					Label = "3";
					AMCL["BHandler"];
					AMCL["MGarrett"];
					AMCL["PGarrett"];
				},
				{
					Label = "4";
					AMCL["OGothena"];
				},
				{
					Label = "5";
					AMCL["UWeapons"];
					AMCL["GWendham"];
					AMCL["LWarren"];
				},
				{
					Label = "6";
					AMCL["UHArmor"];
					AMCL["TWeldon"];
					AMCL["WElling"];
				},
				{
					Label = "7";
					AMCL["ULArmor"];
					AMCL["LNewcomb"];
					AMCL["DBartlett"];
				},
				{
					Label = "8";
					AMCL["MReagents"];
					AMCL["Mordan"];
				},
				{
					Label = "9";
					AMCL["Bshop"];
					AMCL["NaznikS"];
					AMCL["ECairn"];
				},
				{
					Label = "10";
					AMCL["TawnyG"];
					AMCL["TawnyG&"];
					AMCL["TawnyG&1"];
				},
				{
					Label = "11";
					AMCL["GuildCT"];
					AMCL["ROBauhaus"];
					AMCL["EReming"];
					AMCL["CDrakul"];
					AMCL["MPleas"];
				},
				{
					Label = "12";
					AMCL["UCook"];
					AMCL["EBurch"];
					AMCL["RBurch"];
					AMCL["RAndrean"];
				},
				{
					Label = "13";
					AMCL["JPayson"];
				},
				{
					Label = "14";
					AMCL["Balth"];
					AMCL["Balth&"];
					AMCL["Balth&1"];
				}
			},

			-- Apothecarium
			{
				Name = AMCL["Apothe"];
				Color = PURP;
				{
					Label = "1";
					AMCL["dugur"];
				},
				{
					Label = "2";
					AMCL["UHerba"];
					AMCL["MAllie"];
					AMCL["KAllie"];
				},
				{
					Label = "3";
					AMCL["ALuca"];
				},
				{
					Label = "4";
					AMCL["UEnchant"];
					AMCL["LCrowe"];
					AMCL["TWebb"];
				},
				{
					Label = "5";
					AMCL["Parq"];
				},
				{
					Label = "6";
					AMCL["AGant"];
				},
				{
					Label = "7";
					AMCL["Alchemist"];
					AMCL["Algernon"];
					AMCL["DMarsh"];
				},
				{
					Label = "8";
					AMCL["DMFelben"];
					AMCL["MAFaranell"];
					AMCL["MAFaranell&"];
					AMCL["DHHalsey"];
					AMCL["Zinge"];
					AMCL["Fuely"];
					AMCL["Cuely"];
					AMCL["TheodG"];
					AMCL["AKeev"];
				}
			},

			-- War Quarter
			{
				Name = AMCL["WarQuart"];
				Color = BLUE;
				{
					Label = "1";
					AMCL["GerardA"];
					AMCL["LeonaT"];
					AMCL["JoannW"];
				},
				{
					Label = "2";
					AMCL["UBowM"];
					AMCL["AbigS"];
				},
				{
					Label = "3";
					AMCL["UMining"];
					AMCL["BromK"];
					AMCL["SarahK"];
				},
				{
					Label = "4";
					AMCL["UWeapM"];
					AMCL["Abald"];
					PINK..""..AMCL["Crossbow"];
					PINK..""..AMCL["Daggers"];
					PINK..""..AMCL["Polearms"];
					PINK..""..AMCL["One-Handed Sword"];
					PINK..""..AMCL["Two-Handed Sword"];
					AMCL["GeoffH"];
					AMCL["BeniF"];
					AMCL["FranE"];
				},
				{
					Label = "5";
					AMCL["UBlacks"];
					AMCL["JVBrunt"];
					AMCL["SVBrunt"];
					AMCL["MTrem"];
					AMCL["Forge"];
				},
				{
					Label = "6";
					AMCL["UGunsm"];
					AMCL["NAtwood"];
				},
				{
					Label = "7";
					AMCL["HAtwood"];
				},
				{
					Label = "8";
					AMCL["SHouser"];
					AMCL["SRutger"];
				},
				{
					Label = "9";
					AMCL["FLanke"];
					AMCL["FLaza"];
					AMCL["UAelth"];
					AMCL["BFowl"];
					AMCL["ACurt"];
					AMCL["ChristW"];
				}
			},

			-- Magic Quarter
			{
				Name = AMCL["MagQuart"];
				Color = GREN;
				{
					Label = "1";
					AMCL["UStaff"];
					AMCL["SUpton"];
					AMCL["ZaneB"];
				},
				{
					Label = "2";
					AMCL["UTailor"];
					AMCL["RalsF"];
					AMCL["SVCroy"];
					AMCL["Josef"];
					AMCL["Millie"];
					AMCL["LuciC"];
				},
				{
					Label = "3";
					AMCL["OranS"];
					AMCL["SamaS"];
					AMCL["AndrB"];
				},
				{
					Label = "4";
					AMCL["UCarto"];
					AMCL["JorahA"];
				},
				{
					Label = "5";
					AMCL["UBook"];
					AMCL["SalazB"];
				},
				{
					Label = "6";
					AMCL["UReag"];
					AMCL["HannA"];
				},
				{
					Label = "7";
					AMCL["URelic"];
					AMCL["SilasZ"];
				},
				{
					Label = "8";
					AMCL["JList"];
				},
				{
					Label = "9";
					AMCL["CHalg"];
				},
				{
					Label = "10";
					AMCL["UpLevel"];
					AMCL["LMort"];
					AMCL["BIces"];
					AMCL["PorBlasted"];
				},
				{
					Label = "11";
					AMCL["UpLevel"];
					AMCL["RKerw"];
				},
				{
					Label = "12";
					AMCL["UpLevel"];
					AMCL["AHart"];
				},
				{
					Label = "13";
					AMCL["LoLevel"];
					AMCL["LPick"];
					AMCL["KaalS"];
					AMCL["KaelyH"];
					AMCL["PiercS"];
					AMCL["MartS"];
					AMCL["GodrF"];
				},
				{
					Label = "14";
					AMCL["ArmaC"];
					AMCL["LizbC"];
				}
			},

			-- RogQuart
			{
				Name = AMCL["RogQuart"];
				Color = ORNG;
				{
					Label = "1";
					AMCL["UDag"];
					AMCL["CSeat"];
					AMCL["NStee"];
				},
				{
					Label = "2";
					AMCL["UPois"];
					AMCL["EGrav"];
				},
				{
					Label = "3";
					AMCL["MEdra"];
				},
				{
					Label = "4";
					AMCL["ULeat"];
					AMCL["ArthM"];
					AMCL["JoseM"];
					AMCL["GillM"];
					AMCL["KillH"];
				},
				{
					Label = "5";
					AMCL["UBag"];
					AMCL["JonaC"];
				},
				{
					Label = "6";
					AMCL["UEngin"];
					AMCL["FrankL"];
					AMCL["ElizVT"];
					AMCL["GrahVT"];
					AMCL["LucF"];
					AMCL["Forge"];
				},
				{
					Label = "7";
					AMCL["EsteG"];
				},
				{
					Label = "8";
					AMCL["CaroW"];
					AMCL["MileD"];
					AMCL["GregC"];
					AMCL["MennC"];
				},
				{
					Label = "9";
					AMCL["WaltS"];
				}
			},

			-- RoyalQua
			{
				Name = AMCL["RoyalQua"];
				Color = _RED;
				{
					Label = "1";
					AMCL["LadWindr"];
					AMCL["Sharl"];
					AMCL["Varima"];
					AMCL["ASunsor"];
					AMCL["CyssaD"];
				},
				{
					Label = "2";
					AMCL["GrizHalf"];
				},
				{
					Label = "3";
					AMCL["HordeWar"];
					AMCL["RexPix"];
				},
				{
					Label = "4";
					AMCL["SirMalo"];
				},
				{
					Label = "5";
					AMCL["Lyrlia"];
				},
				{
					Label = "6";
					AMCL["KurdB"];
					AMCL["SForth"];
					AMCL["SForth&"];
				},
			},
		},
	}, -- End of Undercity
}

Atlas_RegisterPlugin("AtlasMajorCities", myCategory, myData);

